@@ -2,6 +2,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from aleksis.core.data_checks import DataCheck, IgnoreSolveOption, SolveOption
 
+
 class SyncEventMembers(SolveOption):
     name = "sync_event_members"
     verbose_name = _("Sync members")
@@ -28,9 +29,9 @@ class EventMembersSyncDataCheck(DataCheck):
 
         async_events = []
         for event in Event.objects.all():
-            if not set(event.linked_group.members.values_list("id", flat=True)) == set(event.registrations.values_list(
-                "person", flat=True
-            )):
+            if not set(event.linked_group.members.values_list("id", flat=True)) == set(
+                event.registrations.values_list("person", flat=True)
+            ):
                 async_events.append(event)
 
         for event in async_events:
