@@ -1,10 +1,8 @@
 from datetime import datetime
 from decimal import Decimal
-from typing import Optional
 
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
-from django.dispatch import receiver
 from django.urls import reverse
 from django.utils.text import slugify
 from django.utils.timezone import now
@@ -23,6 +21,7 @@ from aleksis.core.util.email import send_email
 
 from .data_checks import EventMembersSyncDataCheck
 
+
 class RegistrationState(ExtensibleModel):
 
     name = models.CharField(verbose_name=_("Name"), max_length=255)
@@ -149,9 +148,7 @@ class Event(ExtensibleModel):
         return self.display_name
 
     def sync_group_members(self):
-        self.linked_group.members.set(
-            self.registrations.values_list("person", flat=True)
-        )
+        self.linked_group.members.set(self.registrations.values_list("person", flat=True))
 
     def can_register(self, request=None):
         now = datetime.today().date()
@@ -358,11 +355,12 @@ class EventRegistration(ExtensibleModel):
             )
 
     def _get_total_amount(self):
-        total, tax = 0, 0
+        total, total_tax = 0, 0
         for item in self.get_purchased_items():
-            tax += item.price * item.tax_rate / 100
+            tax = item.price * item.tax_rate / 100
             total += item.price + tax
-        return total, tax
+            total_tax += tax
+        return total, total_tax
 
     def __str__(self) -> str:
         return f"{self.event}, {self.person.first_name} {self.person.last_name}"
